@@ -37,8 +37,12 @@
 #include <QDebug>
 #include <QCheckBox>
 #include <QMenu>
+#include <QProcess>
+#include <QFile>
 #include <QPushButton>
-#include <QtDBus>
+#include <QDBusConnection>
+#include <QDBusInterface>
+#include <QDBusConnectionInterface>
 #include <QVBoxLayout>
 
 #define KWALLETMANAGERINTERFACE "org.kde.KWallet"
