@@ -25,7 +25,7 @@ RevokeAuthButton::RevokeAuthButton(const QString &appName, KWallet::Wallet *wall
     _appName(appName),
     _wallet(wallet)
 {
-    setObjectName(QString("Revoke_%1").arg(appName));
+    setObjectName(QStringLiteral("Revoke_%1").arg(appName));
     setText(i18n("Revoke Authorization"));
     connect(this, &RevokeAuthButton::clicked, this, &RevokeAuthButton::onClicked);
 }
